<?php

namespace Drupal\gitlab_api;

use Drupal\Core\Config\ConfigFactoryInterface;
use Gitlab\Client;
use Gitlab\Exception\InvalidArgumentException;

/**
 * Class Api
 *
 * @package Drupal\gitlab_api
 */
class Api {

  /**
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * @var \Gitlab\Client
   */
  protected $client;

  /**
   * Api constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->config = $config_factory->get('gitlab_api.settings');
  }

  /**
   * Initialize client and authenticate session.
   */
  protected function init() {
    if (!isset($this->client)) {
      $this->client = Client::create($this->config->get('url'))
        ->authenticate($this->config->get('token'), Client::AUTH_URL_TOKEN);
    }
  }

  /**
   * @param string $namespace
   * @param string $path
   * @param string $name
   *
   * @return array
   */
  public function createProject($namespace, $path, $name): array {
    $this->init();

    $gitlab_namespace = $this->client->namespaces()->show($namespace);
    if (!$gitlab_namespace) {
      throw new InvalidArgumentException('Invalid namespace');
    }

    return $this->client->projects()->create($name, [
      'namespace_id' => $gitlab_namespace['id'],
      'path' => $path,
    ]);
  }

}
